@@ -17,7 +17,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#else
+#define PREFIX "/usr"
+#endif
 
 #include <kgenericfactory.h>
 #include <tdelocale.h>
@@ -70,7 +74,7 @@ install::install( const TQString &url, TQWidget *parent, const char *name, const
 
 	if ((pipe_prefix = popen(prefixcommand.c_str(), "r")) == NULL)
 	{
-		m_kdePrefix = "/usr";
+		m_kdePrefix = PREFIX;
 	}
 	else {
 		fgets(prefix_result, 2048, pipe_prefix);
@@ -163,14 +167,14 @@ void install::page3()
 	titleTextLabel->setText( "<b>"+i18n( "Resynchronize Package Index")+"</b>" );
 	closePushButton->hide();
 
-	TQStrList run; run.append( m_kdePrefix + "/share/kdpkg/sh/kdpkg-sh" );
+	TQStrList run; run.append( m_kdePrefix.local8Bit() + "/share/kdpkg/sh/kdpkg-sh" );
 		run.append( "update" );
 
 	TQWidget *consoleWidget = new console(this, run );
  	widgetStack->addWidget(consoleWidget, 4);
 	widgetStack->raiseWidget(4);
 
-	connect( consoleWidget, TQT_SIGNAL( finished(bool) ), this, TQT_SLOT( page1() ));
+	connect( consoleWidget, TQ_SIGNAL( finished(bool) ), this, TQ_SLOT( page1() ));
 }
 
 
@@ -186,18 +190,18 @@ void install::page4()
 	if( !removePkg )
 		removePkg = "none";
 
-	TQStrList run; run.append( m_kdePrefix + "/share/kdpkg/sh/kdpkg-sh" );
+	TQStrList run; run.append( m_kdePrefix.local8Bit() + "/share/kdpkg/sh/kdpkg-sh" );
 		run.append( "install" );
-		run.append( path );
-		run.append( installPkg );
-		run.append( removePkg );
+		run.append( path.local8Bit() );
+		run.append( installPkg.local8Bit() );
+		run.append( removePkg.local8Bit() );
 
 	TQWidget *consoleWidget = new console(this, run );
 	widgetStack->addWidget(consoleWidget, 5);
 	widgetStack->raiseWidget(5);
 
-	//connect( consoleWidget, TQT_SIGNAL( finished(bool) ), this, TQT_SLOT( close() ));
-	connect( consoleWidget, TQT_SIGNAL( finished(bool) ), this, TQT_SLOT( page5() ));
+	//connect( consoleWidget, TQ_SIGNAL( finished(bool) ), this, TQ_SLOT( close() ));
+	connect( consoleWidget, TQ_SIGNAL( finished(bool) ), this, TQ_SLOT( page5() ));
 
 
 }
